CCL: /home/chisarie/Documents/lsst_ccl/CCL/tests/ccl_test_growth.py File Reference

CCL

Namespaces | Functions | Variables
ccl_test_growth.py File Reference

## Namespaces
| ccl_test_growth

## Functions
def | ccl_test_growth.read_growth_test_file ()
def | ccl_test_growth.compare_growth (z, gfac_bench, Omega_v, w0, wa)
def | ccl_test_growth.test_growth_model_0 ()
def | ccl_test_growth.test_growth_model_1 ()
def | ccl_test_growth.test_growth_model_2 ()
def | ccl_test_growth.test_growth_model_3 ()
def | ccl_test_growth.test_growth_model_4 ()
def | ccl_test_growth.test_mgrowth ()

## Variables
int | ccl_test_growth.GROWTH_TOLERANCE = 1e-4
float | ccl_test_growth.Omega_c = 0.25
float | ccl_test_growth.Omega_b = 0.05
int | ccl_test_growth.N_nu_rel = 0.
int | ccl_test_growth.N_nu_mass = 0.
int | ccl_test_growth.m_nu = 0.
float | ccl_test_growth.h = 0.7
float | ccl_test_growth.A_s = 2.1e-9
float | ccl_test_growth.n_s = 0.96
| ccl_test_growth.Omega_v_vals = np.array([0.7, 0.7, 0.7, 0.65, 0.75])
| ccl_test_growth.w0_vals = np.array([-1.0, -0.9, -0.9, -0.9, -0.9])
| ccl_test_growth.wa_vals = np.array([0.0, 0.0, 0.1, 0.1, 0.1])